#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdlib.h>
#define  SCRCTL_GET_ROTATION 0x413c

#define DEV_APM_BIOS  "/dev/apm_bios"

void usage(char *name)
{
  printf ("Usage: %s [-e]\n", name);
  printf ("Report on Zaurus SL-C7x0 hinge state.\n");
  printf ("With no arguments, display hinge state on stdout.\n");
  printf ("With -e, report hinge state in exit code:\n");
  printf ("  10=landscape; 12=portrait; 13=closed\n");
  exit (1);
}

int main ( int argc, char ** argv) 
{
    int handle;
    int retval;
    int flag_e = 0;
    int i;

    for (i = 1; i < argc; i++)
      {
	if (!strcmp (argv[i], "-e"))
	  flag_e = 1;
	else
	  usage (argv[0]);
      }

    handle = open (DEV_APM_BIOS, O_RDWR|O_NONBLOCK);
    if (handle < 0) 
      {
	perror (DEV_APM_BIOS);
	return -1;
      }

    retval = ioctl (handle, SCRCTL_GET_ROTATION);
    close (handle);

    if (flag_e)
      {
	exit (10 + retval);
      }

    switch (retval)
      {
      case 3:
	printf("%s: Case closed\n", argv[0]);
	break;
      case 2:
	printf("%s: Case open portrait\n", argv[0]);
	break;
      case 0:
	printf("%s: Case open landscape\n", argv[0]);
	break;
      default:
	printf("%s: I dunno what state %i is ?\n", argv[0], retval);
	break;
      }

    exit (0);
}
